from django.contrib.auth.models import User
from django.urls import reverse
from games.models import Platform
from rest_framework import status
from rest_framework.test import APITestCase, force_authenticate
import json


class PlatformTest(APITestCase):

    @classmethod
    def setUpTestData(cls):
        cls.superuser = User.objects.create_superuser(
            'admin',
            'admin@localhost',
            'admin')

    def test_create_platform(self):
        """
        Check we can create a platform object.
        """
        url = reverse('platform-list')
        data = {'name': 'GP2X'}
        self.client.force_authenticate(user=self.superuser)
        response = self.client.post(url, data, format='json')
        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
        self.assertEqual(Platform.objects.count(), 1)
        self.assertEqual(Platform.objects.get().name, 'GP2X')

    def test_sorted_platform(self):
        """
        Check that platform list is sorted.
        """
        Platform.objects.create(name='GP2X')
        Platform.objects.create(name='3DS')
        Platform.objects.create(name='Game Boy')
        Platform.objects.create(name='Amiga')
        url = reverse('platform-list')
        self.client.force_authenticate(user=self.superuser)
        response = self.client.get(url, format='json')
        sorted_platforms = list(
            Platform.objects.all().order_by('name').values_list(
                'name', flat=True))
        platforms = [x.get('name') for x in json.loads(response.content)]
        self.assertEqual(platforms, sorted_platformss)
